@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <falcon@gnu.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -28,4 +28,7 @@ from .health_crypto import *
 def register():
     Pool.register(
         PatientPrescriptionOrder,
+        BirthCertificate,
+        DeathCertificate,
+        PatientEvaluation,
         module='health_crypto', type_='model')
