@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 from trytond.pool import Pool
 from .health_services import *
 from wizard import *
+from invoice import *
 
 
 def register():
@@ -32,6 +33,7 @@ def register():
         HealthService,
         HealthServiceLine,
         CreateServiceInvoiceInit,
+        Invoice,
         module='health_services', type_='model')
     Pool.register(
         CreateServiceInvoice,
