@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #
@@ -21,6 +21,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################
+import datetime
 from trytond.model import ModelView
 from trytond.wizard import Wizard, StateTransition, StateView, Button
 from trytond.transaction import Transaction
@@ -57,11 +58,14 @@ class CreateServiceInvoice(Wizard):
             })
 
     def transition_create_service_invoice(self):
-        HealthService = Pool().get('gnuhealth.health_service')
-        Invoice = Pool().get('account.invoice')
-        Party = Pool().get('party.party')
-        Journal = Pool().get('account.journal')
+        pool = Pool()
+        HealthService = pool.get('gnuhealth.health_service')
+        Invoice = pool.get('account.invoice')
+        Party = pool.get('party.party')
+        Journal = pool.get('account.journal')
 
+        currency_id = Transaction().context.get('currency')
+        
         services = HealthService.browse(Transaction().context.get(
             'active_ids'))
         invoices = []
@@ -69,14 +73,31 @@ class CreateServiceInvoice(Wizard):
         #Invoice Header
         for service in services:
             if service.state == 'invoiced':
-                    self.raise_user_error('duplicate_invoice')
+                self.raise_user_error('duplicate_invoice')
+            if service.invoice_to:
+                party = service.invoice_to
+            else:
+                party = service.patient.name
             invoice_data = {}
             invoice_data['description'] = service.desc
-            invoice_data['party'] = service.patient.name.id
+            invoice_data['party'] = party.id
             invoice_data['type'] = 'out_invoice'
-            invoice_data['account'] = \
-                service.patient.name.account_receivable.id
-            
+            invoice_data['invoice_date'] = datetime.date.today()
+            invoice_data['account'] = party.account_receivable.id
+            invoice_data['patient'] = service.patient.id
+            invoice_data['health_service'] = service.id
+
+            ctx = {}
+            sale_price_list = None
+            if hasattr(party, 'sale_price_list'):
+                sale_price_list = party.sale_price_list
+
+            if sale_price_list:
+                ctx['price_list'] = sale_price_list.id
+                ctx['sale_date'] = datetime.date.today()
+                ctx['currency'] = currency_id
+                ctx['customer'] = party.id
+
             journals = Journal.search([
                 ('type', '=', 'revenue'),
                 ], limit=1)
@@ -88,38 +109,44 @@ class CreateServiceInvoice(Wizard):
 
             invoice_data['journal'] = journal.id
 
-            party_address = Party.address_get(service.patient.name,
-                type='invoice')
+            party_address = Party.address_get(party, type='invoice')
             if not party_address:
                 self.raise_user_error('no_invoice_address')
-            invoice_data['invoice_address'] = party_address.id 
+            invoice_data['invoice_address'] = party_address.id
             invoice_data['reference'] = service.name
 
-
-            if not service.patient.name.customer_payment_term:
+            if not party.customer_payment_term:
                 self.raise_user_error('no_payment_term')
 
-            invoice_data['payment_term'] = \
-                    service.patient.name.customer_payment_term.id
+            invoice_data['payment_term'] = party.customer_payment_term.id
             
             #Invoice Lines
             seq = 0
             invoice_lines = []
             for line in service.service_line:
                 seq = seq + 1
-                account = line['product'].template.account_revenue_used.id
-                if line['to_invoice']:
+                account = line.product.template.account_revenue_used.id
+
+                if sale_price_list:
+                    with Transaction().set_context(ctx):
+                        unit_price = sale_price_list.compute(party,
+                        line.product, line.product.list_price,
+                        line.qty, line.product.default_uom)
+                else:
+                    unit_price = line.product.list_price
+
+                if line.to_invoice:
                     invoice_lines.append(('create', [{
-                            'product': line['product'].id,
-                            'description': line['desc'],
-                            'quantity': line['qty'],
+                            'product': line.product.id,
+                            'description': line.desc,
+                            'quantity': line.qty,
                             'account': account,
-                            'unit': line['product'].default_uom.id,
-                            'unit_price': line['product'].list_price,
-                            'sequence': seq
+                            'unit': line.product.default_uom.id,
+                            'unit_price': unit_price,
+                            'sequence': seq,
                         }]))
                 invoice_data['lines'] = invoice_lines
-        
+
             invoices.append(invoice_data)
 
         Invoice.create(invoices)
@@ -128,4 +155,3 @@ class CreateServiceInvoice(Wizard):
         HealthService.write(services, {'state': 'invoiced'})
 
         return 'end'
-
