@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2014 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2014 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 
 from trytond.pool import Pool
 from .health_surgery import *
+from report import *
 
 def register():
     Pool.register(
@@ -31,3 +32,6 @@ def register():
         Operation,
         PatientData,
         module='health_surgery', type_='model')
+    Pool.register(
+        SurgeryReport,
+        module='health_surgery', type_='report')
